#
# spec file for package pitivi
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pitivi
Version:        2022.06
Release:        bp156.4.3
Summary:        Video editing software
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://www.pitivi.org/
Source0:        https://download.gnome.org/sources/pitivi/2022/%{name}-%{version}.tar.xz
# Fix for startup error "ImportError: cannot import name 'MouseButton'"
Patch01:        bsc1207084_MouseButton.patch
BuildRequires:  fdupes
BuildRequires:  gnome-doc-utils-devel >= 0.18.0
BuildRequires:  gobject-introspection >= 1.31.1
BuildRequires:  hicolor-icon-theme
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-cairo-devel
BuildRequires:  python3-gobject
BuildRequires:  shared-mime-info
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.14.1
BuildRequires:  pkgconfig(gstreamer-transcoder-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0) >= 1.10.2
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
Requires:       gstreamer-transcoder >= 1.8.2
Requires:       python3-cairo
Requires:       python3-gobject
Requires:       python3-gst >= 1.17.90
Requires:       python3-matplotlib-gtk3
Requires:       python3-numpy
# We need a minimal version of the GES-1.0 package, so we have to specify it manually
Requires:       typelib-1_0-GES-1_0 >= 1.17.90
Requires:       typelib-1_0-Gst-1_0 >= 1.17.90
# Pitivi can use the Frei0r plugins, and since this enables lots of effects, we
# really want that by default if possible
Recommends:     frei0r-plugins

%description
Pitivi is a non-linear, featureful movie editor.
It supports realtime trimming previews, ripple and roll editing,
grouping and snapping, realtime assets management and searching,
playhead-centric zooming and editing, non-modal cutting, detachable
interface components, smooth scrolling, and automatic zoom
adjustment.

%lang_package

%prep
%autosetup -p1
sed -i -e '1s!/usr/bin/env !/usr/bin/!' bin/pitivi.in

# Remove bunlded gst-transcoder
rm -rf subprojects/gst-transcoder

%build
%meson -Ddisable-help=false
%meson_build

python3 -m compileall -q -j 0 .

%install
%meson_install
rm -v %{buildroot}%{_libdir}/pitivi/python/pitivi/coptimizations/renderer.c

%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{_libdir}

%post
if test -x usr/bin/update-mime-database ; then
  usr/bin/update-mime-database usr/share/mime >/dev/null
fi

%postun
if test -x usr/bin/update-mime-database ; then
  usr/bin/update-mime-database usr/share/mime >/dev/null
fi

%files
%license COPYING
%doc AUTHORS NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/pitivi
%{_libdir}/pitivi/
%{_datadir}/applications/org.pitivi.Pitivi.desktop
%{_datadir}/icons/hicolor/*/*/*.*
%{_datadir}/metainfo/org.pitivi.Pitivi.appdata.xml
%{_datadir}/mime/packages/org.pitivi.Pitivi-mime.xml
%{_datadir}/pitivi/

%files lang -f %{name}.lang

%changelog
* Fri Oct 20 2023 Alessandro Soraruf <asoraruf@ntd.homelinux.org>
- Add bsc1207084_MouseButton.patch to fix startup crash with error:
  "ImportError: cannot import name 'MouseButton'" (bsc#1207084)
* Wed Mar 15 2023 Max Lin <mlin@suse.com>
- pkgconfig(gst-validate-1.0) is only needed for test which that
  don't run
* Sun Jun 26 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2022.06:
  + Object tracking and blurring.
  + Beat detection and snapping clips to detected beats.
  + Title clip text border and shadow.
  + Allow maintaining aspect-ratio when resizing clips.
  + Added Source blending mode.
  + Easier to fade in/out a clip.
  + Playback sound VU meter.
  + Cut clips to paste them at a different position.
- Drop ddf2369d1fc6fddd63f676cc905a8b8e96291a4c.patch
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add ddf2369d1fc6fddd63f676cc905a8b8e96291a4c.patch: Fix build
  with meson 0.60 and newer.
- Drop pitivi-rpmlintrc, no longer needed.
* Thu Nov 11 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on python3-nose.
* Thu Nov  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Replace enable-docs=true option with new disable-help=false
  option passed to meson.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Jun  1 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 2021.05:
  + Clips in the Media Library can be tagged.
  + Drag a keyframe vertically or horizontally by pressing Ctrl.
  + Keyboard shortcuts to seek to the previous/next marker.
* Thu Feb  4 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 2021.01:
  + The Render dialog has been further simplified.
  + Lots of bugfixes.
* Sat Nov 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(gst-transcoder-1.0) with
  pkgconfig(gstreamer-transcoder-1.0) BuildRequires.
* Tue Oct 27 2020 dimstar@opensuse.org
- Update to version 2020.09.2:
  + timeline: Fix update_clips_asset.
  + Updated translations.
* Sat Oct 24 2020 Marcus Rueckert <mrueckert@suse.de>
- Bump requires for GST and GES to the version required for pitivi.
* Thu Oct 15 2020 dimstar@opensuse.org
- Update to version 2020.09.1:
  + Updated translations.
* Tue Oct  6 2020 dimstar@opensuse.org
- Update to version 2020.09:
  + A plugin system allows extending the Pitivi functionality
    medium-term, targeted for teams of editors.
  + A developer console plugin allows interacting with the project
    in a Python console.
  + Custom UI replaces the automatically generated UI for a handful
    of effects.
  + Easy Ken-Burns effect.
  + The new Greeter perspective replaces the Welcome wizard dialog
    and allows a slick selection of a recently opened project.
  + When being resized, the Viewer shows the percent of the actual
    widget size in relation to the project video size.
  + The Viewer size snaps at 50%% when being resized.
  + Scaled proxies if optimized media is too much for your machine.
  + Timeline markers.
  + Support for nested timelines by importing entire XGES files as
    a clip.
  + The Effects Library has been redesigned to allow quick access
    to effects.
  + Ability to favorite effects in the Effects Library.
  + Improved workflow for adding effects.
  + The refreshed clip effects UI allows working on multiple
    effects at a time.
  + Refactored Media Library using same logic for different view
    modes.
  + Refactored Render Dialog UI to avoid overwhelming people. Tell
    us what you think about it.
  + Restoring the editing state when reopening a project.
  + Safe areas visualization in the Viewer.
  + Easy alignment for video clips.
  + Composition guidelines in the Viewer.
  + Solid color clips.
  + Ability to mute or hide an entire layer.
  + Interactive intro so newcomers get familiar with the names of
    the UI elements.
  + The action search is a shortcut to everything possible in the
    timeline, if you can find it. Press "/".
  + New keyboard shortcuts for pros.
- Drop pitivi-Support-python-3.8.patch: fixed upstream.
* Mon Mar 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add pitivi-Support-python-3.8.patch: Support building against
  python 3.8.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Sep 16 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Patch pitivi.in before build to ensure reproducible builds
  (boo#1102408)
* Mon Sep 10 2018 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 0.999:
  + Selecting a range of clips can be done by clicking followed by
    Shift+click.
  + The advanced settings of the h264 encoder allow specifying a
    Profile.
  + Rendering non-square pixels was broken and has been disabled.
  + The xges files have an icon associated.
  + The Save and Render buttons in the headerbar have been moved on
    the right side.
  + Lots of bug fixing.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
* Thu Jun 14 2018 mcepl@suse.com
- Clean up the spec, make all warnings to go away.
- Add pitivi-rpmlintrc to disable warnings, which don't make
  sense for this package (that overflow of documentation are
  locale, not true documentation).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Sep 21 2017 luc14n0@linuxmail.org
- Update to version 0.99:
  + Many performance improvements.
  + Lots of bug fixing.
- Add meson BuildRequires, and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson Build System.
- Add pkgconfig(gstreamer-1.0) BuildRequires: new dependency.
- Drop intltool BuildRequires: no longer needed.
- Drop %%desktop_database_*, %%icon_theme_cache_* and
  %%mime_database_* post/postun macros: the functionality is now
  covered by file triggers.
* Sun Jul  2 2017 zaitor@opensuse.org
- Update to version 0.98.1:
  + Bug fix release to ensure compatibility with Gst 1.12.
* Sun Feb  5 2017 antoine.belvire@opensuse.org
- Add gstreamer-transcoder as runtime dependency in order to avoid
  crashes when importing files (boo#1023627).
* Wed Dec  7 2016 dimstar@opensuse.org
- Update to version 0.98:
  + Customizable keyboard shortcuts.
  + Used the warnings printed by GTK 3.22 to fix issues in the
    timeline widget.
  + Lots of bug fixing, mostly on the timeline.
- Drop pitivi-git-is-optional.patch and
  pitivi-translate-appdata.patch: fixed upstream.
* Thu Oct 13 2016 dimstar@opensuse.org
- Add pitivi-translate-appdata.patch: Fix translation of
  pitivi.appdata.xml.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 0.97.1:
  + The rendering dialog has been reworked to clearly state what
    encoders and muxer are officially supported (and the GES
    integration tests have been added to check those).
  + The build system has been ported to Meson and gst-transcoder is
    now a subproject.
  + Usual bug fixes.
- Add pkgconfig(gst-transcoder-1.0) BuildRequires: new dependency
  (which was shipped as a submodule in the tarball; remove the
  bundled version during prep).
- Add meson and python3-nose BuildRequires: build system was ported
  to meson.
- No longer use configure macro: upstream uses meson, which
  provides configure for convenience, but it's not autoconf.
- Add pitivi-git-is-optional.patch: Do not require 'git' to be
  present when building released tarballs.
* Fri Jul  1 2016 zaitor@opensuse.org
- Update to version 0.96:
  + Besides the usual cleanup and bug squashing, this release
    brings a fundamental feature which greatly improves the edit
    experience. Now you can edit and render a video project with
    any video files with great accuracy, thanks to proxy files.
* Wed Jan 20 2016 antoine.belvire@laposte.net
- Add missing requirement: python3-matplotlib-gtk3 (pitivi 0.95
  doesn't start without it).
* Wed Dec 16 2015 dimstar@opensuse.org
- Update to version 0.95:
  + The timeline has been rewritten purely in GTK+.
  + The glimagesink video rendering widget was replaced by
    gtk(gl)sink.
  + The clip transformation box has been reimplemented.
  + Direct importing to the timeline.
  + Ability to copy and paste clips across the timeline.
  + Integration with GstValidate and the "scenarios" system.
  + Rewritten video mixing elements.
  + We finally killed GNonLin.
  + Now compatible again with smaller screen resolutions.
  + Massive bug fixing all over the place.
- Add pkgconfig(gstreamer-1.0), pkgconfig(gstreamer-video-1.0) and
  pkgconfig(gtk+-3.0) BuildRequires: new dependencies.
- Drop gstreamer-plugin-gnonlin Requires: no longer needed.
* Mon Jun  1 2015 zaitor@opensuse.org
- Add python3-cairo requires: yet an other hard dependency to
  start pitivi (boo#905667).
* Tue Nov 18 2014 zaitor@opensuse.org
- Add python3-numpy and python3-gst requires: hard dependencies to
  start pitivi.
* Tue Nov  4 2014 dimstar@opensuse.org
- Update to version 0.94:
  + The main toolbar and menubar have been replaced by a headerbar
    and menubutton, saving a significant amount of precious
    vertical space and using the horizontal space better.
  + The viewer has been ported to use a GStreamer GL video output
    sink instead of the Clutter sink. This solves crashes when
    running Pitivi outside of GNOME Shell and is expected to be a
    more future-proof solution.
  + We dropped our use of CoGL APIs, namely path_round_rectangle
    which caused crashes on various Linux distributions shipping a
    broken version of CoGL.
  + Pitivi has been ported to Python 3.
  + Text wrapping in the rendering progress dialog and title editor
    has been fixed.
  + Effects can now be reordered within a clip's properties.
  + The default positioning of UI components (when starting from a
    fresh install) has been improved to be balanced properly.
  + Undocked window components do not shift position on startup
    anymore.
  + Docked window components do not shift position on startup
    anymore, when the window is not maximized.
  + The title editor's UI has been simplified, and now supports
    decimal font sizes.
  + Educational infobars throughout the UI have been tweaked to
    make their colors less intrusive.
  + The user manual is now up to date with the state of the new
    Pitivi series.
  + Port deprecated GTK+ widgets to new ones.
  + Timeline UI animations have been tweaked.
  + Code refactoring and cleanup all over the place.
  + Various build and packaging fixes.
  + Various fixes to the test suite.
  + Various other bugs have been corrected.
- Update BuildRequires for python3 port:
  + Replace python-cairo-devel with python3-cairo-devel and
    python-devel with python3-gobject.
  + Replace python-gobject requires by python3-gobject: pitivi has
  been ported to Python3.
- Add explicit typelib-1_0-GES-1_0 Requires, so we can specify the
  minimum version.
* Mon Oct 20 2014 dimstar@opensuse.org
- Add gstreamer-plugin-gnonlin requires: hard dependency to
  start pitivi.
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 0.93:
  + Port the viewer and media file previewers to use a Clutter
    video output sink.
  + Visual refinements to the timeline (clip positioning, borders,
    selections).
  + Improvements to the ruler and timecode display.
  + Allow importing MPEG-TS/AVCHD files.
  + Fixes and improvements to the timeline's clip thumbnailers.
  + Clip thumbnailing in the media library, better import error
    handling.
  + Various fixes to the application version checking.
  + Rework the way dependencies are checked on startup.
  + Make some features contextual and cleanup menus.
  + Many content updates to the user manual.
  + Papercut fixes to keyframe curves.
  + Many fixes for rendering.
  + Fix pylint errors.
  + Various fixes to the automated test suite.
  + Code refactoring and cleanup all over the place.
  + Fixes for AppData XML spec compliance.
  + Various build and packaging fixes.
* Tue Nov 26 2013 dimstar@opensuse.org
- Update to version 0.92:
  + Fix a bug where transitions would stop working.
  + Fix the handling of rendering parameters.
  + Fixes for the keyframes UI in the timeline.
  + Usability improvements for the welcome dialog.
  + Update the preview immediately when adding an effect.
  + Fixes for AppData XML spec compliance.
  + Various build and packaging fixes.
  + Drop the PyXDG dependency.
- Changes from version 0.9.1:
  + Replacing the core of Pitivi by GES; 20 thousand lines of
    code removed.
  + Porting to GStreamer 1.x.
  + Porting to GTK+ 3.x.
  + Replacing GooCanvas by Clutter for the timeline.
  + An automated UI test suite, with many checks for
    mission-critical parts.
  + Fixing hundreds of bugs.
  + Implementing many new features.
  + UI polish all over the place.
  + Refactoring pretty much the entire codebase.
  + See http://wiki.pitivi.org/wiki/0.91 for details
  + Updated translations.
- Add itstool and python-cairo-devel: New dependencies.
- Drop pitivi-help_figures.patch: fixed upstream.
- Remove codecscontainers.jpg and mainwindow.jpg: included in the
  tarball now.
- Drop static python requires: python-gnome, python-gconf,
  python-goocanvas, pythong-gstreamer-0_10-, python-gtk,
  python-setuptools, python-xdg and python-zopeinterface: pitivi
  now uses the GI repository.
- Drop gstreamer-0_10 and gstreamer-0_10-plugin-gnonlin Requires:
  pitivi has been ported to GStreamer 1.0.
- Add gobject-introspection BuildRequires in order to get automatic
  typelib() Requires.
- Add python-gobject Requires.
* Wed Jul  4 2012 dimstar@opensuse.org
- Add pitivi-help_figures.patch: Fix an encoding error in the
  distributed Makefile.am and Makefile.in and change
  mainwindow.png to mainwindow.jpg.
- Add codecscontainers.jpg as source. Due to the encoding error
  addressed by above patch, this file was not present in the
  tarball.
- Add mainwindow.jpg as source: upstream accidentally references
  a .png file in the makefiles, but the real file is a .jpg.
* Thu May  3 2012 badshah400@gmail.com
- Update to version 0.15.2:
  + Bug fixed for a regression introduced by 0.15.1
  + Updated translations.
* Sat Feb 25 2012 vuntz@opensuse.org
- Update to version 0.15.1:
  + Bug fix release to ensure compatibility with Gst "good" plugins
    >0.10.29
  + Minor string fixes and additions to the user manual
  + Updated translations.
* Thu Sep 29 2011 vuntz@opensuse.org
- Add frei0r-plugins Recommends: those plugins add many useful
  video effects to Pitivi, which makes the experience of using it
  much better.
* Wed Sep 28 2011 dimstar@opensuse.org
- Update to version 0.15.0:
  + A new transformation feature allows resizing, panning and
    cropping clips directly in the previewer
  + Automatic clip alignment by analyzing soundtracks to sync
    multicamera footage
  + Ability to have presets for rendering
  + Default set of project settings and rendering presets
  + Cleaner preferences dialog
  + Integrated offline user manual
  + Cleaner advanced codec settings dialog
  + Improved video thumbnailing performance
  + "Soft depedencies" manager to warn the user of features
    requiring additional packages
  + Port to gtkbuilder
  + Respect GNOME's button icons setting
  + Improved startup time
  + Code cleanups and remove dead code
  + Properly show property descriptions (blurbs) for advanced codec
    settings.
* Sat Aug 13 2011 dimstar@opensuse.org
- Update to version 0.14.2:
  + Transformation UI directly in the video viewer
  + Auto-aligner feature
  + User manual in mallard
  + Soft dependency manager
  + UI enhancements
  + Code cleanup
- Add gnome-doc-utils-devel and pkg-config BuildRequires.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 0.14.1:
  + Remove the libglade dependency
  + Move glade, icons and pixmap files to a separate data/ dir
  + Reorganized the menus
  + UI enhancements
  + Code cleanup
* Thu Jun  9 2011 vuntz@opensuse.org
- On 11.4 and later, change python-gnome Requires to python-gconf
  since this is the only module being used from python-gnome.
* Fri Jun  3 2011 dimstar@opensuse.org
- Update to version 0.14.0:
  + Remove hal dependency
  + Several bug fixes.
- Add python-xdg Requires.
* Fri May 27 2011 dimstar@opensuse.org
- Update to version 0.13.9.90:
  + Audio and video effects
  + Completely redesigned project settings dialog, with the ability
    to create presets
  + Completely redesigned rendering dialog
  + Welcome dialog that helps you start a project or load recent
    projects in two clicks
  + Ability to preview video, audio and image files before
    importing
  + Add a "best fit" zoom button
  + Ability to jump to an exact position in the timeline
  + Ability to specify custom aspect ratios and framerates
  + Show a progress bar when loading projects
  + 300%% faster project timeline loading
  + Search bar in the Media Library
  + Ability to detach all the tabs and the previewer
  + New manpage
  + Commandline render mode
  + Use the standard infobar widget all around
  + Lots of bug fixing.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Add shared-mime-info BuildRequires to have the %%mime_database*
  macros.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Oct 15 2010 coolo@novell.com
- Fix dependencies: Require python-gstreamer-0_10 instead of non-
  existing python-gstreamer.
* Wed Sep 22 2010 dimstar@opensuse.org
- Update to version 0.13.5:
  + periodic backup of the current project file.
  + easy crossfading transitions of overlapping clips.
  + better icons for link and group operations.
  + new add keyframe button.
  + fixed support for the missing plugins installer.
  + improved support for pictures.
  + various performance improvements.
* Sun Aug 29 2010 vuntz@opensuse.org
- Initial package (version 0.13.4).
